@@ -5,7 +5,7 @@
 #
 # Author: Giovanni Cannata
 #
-# Copyright 2013, 2014, 2015, 2016, 2017 Giovanni Cannata
+# Copyright 2013 - 2020 Giovanni Cannata
 #
 # This file is part of ldap3.
 #
@@ -25,13 +25,17 @@
 from pyasn1.error import PyAsn1Error
 
 from .. import SEQUENCE_TYPES, STRING_TYPES, get_config_parameter
-from ..core.exceptions import LDAPControlError, LDAPAttributeError, LDAPObjectClassError
+from ..core.exceptions import LDAPControlError, LDAPAttributeError, LDAPObjectClassError, LDAPInvalidValueError
 from ..protocol.rfc4511 import Controls, Control
 from ..utils.conv import to_raw, to_unicode, escape_filter_chars, is_filter_escaped
+from ..protocol.formatters.standard import find_attribute_validator
 
 
 def attribute_to_dict(attribute):
-    return {'type': str(attribute['type']), 'values': [str(val) for val in attribute['vals']]}
+    try:
+        return {'type': str(attribute['type']), 'values': [str(val) for val in attribute['vals']]}
+    except PyAsn1Error:  # invalid encoding, return bytes value
+        return {'type': str(attribute['type']), 'values': [bytes(val) for val in attribute['vals']]}
 
 
 def attributes_to_dict(attributes):
@@ -43,25 +47,28 @@ def attributes_to_dict(attributes):
 
 
 def referrals_to_list(referrals):
-    return [str(referral) for referral in referrals if referral] if referrals else None
+    if isinstance(referrals, list):
+        return [str(referral) for referral in referrals if referral] if referrals else None
+    else:
+        return [str(referral) for referral in referrals if referral] if referrals is not None and referrals.hasValue() else None
 
 
 def search_refs_to_list(search_refs):
     return [str(search_ref) for search_ref in search_refs if search_ref] if search_refs else None
 
 
+def search_refs_to_list_fast(search_refs):
+    return [to_unicode(search_ref) for search_ref in search_refs if search_ref] if search_refs else None
+
+
 def sasl_to_dict(sasl):
-    return {'mechanism': str(sasl['mechanism']), 'credentials': str(sasl['credentials'])}
+    return {'mechanism': str(sasl['mechanism']), 'credentials':  bytes(sasl['credentials']) if sasl['credentials'] is not None and sasl['credentials'].hasValue() else None}
 
 
 def authentication_choice_to_dict(authentication_choice):
     return {'simple': str(authentication_choice['simple']) if authentication_choice.getName() == 'simple' else None, 'sasl': sasl_to_dict(authentication_choice['sasl']) if authentication_choice.getName() == 'sasl' else None}
 
 
-def decode_referrals(referrals):
-    return [str(referral) for referral in referrals if referral] if referrals else None
-
-
 def partial_attribute_to_dict(modification):
     try:
         return {'type': str(modification['type']), 'value': [str(value) for value in modification['vals']]}
@@ -82,7 +89,13 @@ def attributes_to_list(attributes):
 
 
 def ava_to_dict(ava):
-    return {'attribute': str(ava['attributeDesc']), 'value': str(ava['assertionValue'])}
+    try:
+        return {'attribute': str(ava['attributeDesc']), 'value': escape_filter_chars(str(ava['assertionValue']))}
+    except Exception:  # invalid encoding, return bytes value
+        try:
+            return {'attribute': str(ava['attributeDesc']), 'value': escape_filter_chars(bytes(ava['assertionValue']))}
+        except Exception:
+            return {'attribute': str(ava['attributeDesc']), 'value': bytes(ava['assertionValue'])}
 
 
 def substring_to_dict(substring):
@@ -92,16 +105,19 @@ def substring_to_dict(substring):
 def prepare_changes_for_request(changes):
     prepared = dict()
     for change in changes:
-        prepared[change['attribute']['type']] = (change['operation'], change['attribute']['value'])
+        attribute_name = change['attribute']['type']
+        if attribute_name not in prepared:
+            prepared[attribute_name] = []
+        prepared[attribute_name].append((change['operation'], change['attribute']['value']))
     return prepared
 
 
 def build_controls_list(controls):
-    """
-    controls is a list of Control() or tuples
-    each tuple must have 3 elements: the control OID, the criticality, the value
+    """controls is a sequence of Control() or sequences
+    each sequence must have 3 elements: the control OID, the criticality, the value
     criticality must be a boolean
     """
+
     if not controls:
         return None
 
@@ -120,21 +136,21 @@ def build_controls_list(controls):
                 built_control['controlValue'] = control[2]
             built_controls.setComponentByPosition(idx, built_control)
         else:
-            raise LDAPControlError('control must be a tuple of 3 elements: controlType, criticality (boolean) and controlValue (None if not provided)')
+            raise LDAPControlError('control must be a sequence of 3 elements: controlType, criticality (boolean) and controlValue (None if not provided)')
 
     return built_controls
 
 
-def validate_assertion_value(schema, name, value, auto_escape, auto_encode):
+def validate_assertion_value(schema, name, value, auto_escape, auto_encode, validator, check_names):
     value = to_unicode(value)
     if auto_escape:
         if '\\' in value and not is_filter_escaped(value):
             value = escape_filter_chars(value)
-    value = validate_attribute_value(schema, name, value, auto_encode)
+    value = validate_attribute_value(schema, name, value, auto_encode, validator=validator, check_names=check_names)
     return value
 
 
-def validate_attribute_value(schema, name, value, auto_encode):
+def validate_attribute_value(schema, name, value, auto_encode, validator=None, check_names=False):
     conf_classes_excluded_from_check = [v.lower() for v in get_config_parameter('CLASSES_EXCLUDED_FROM_CHECK')]
     conf_attributes_excluded_from_check = [v.lower() for v in get_config_parameter('ATTRIBUTES_EXCLUDED_FROM_CHECK')]
     conf_utf8_syntaxes = get_config_parameter('UTF8_ENCODED_SYNTAXES')
@@ -142,16 +158,27 @@ def validate_attribute_value(schema, name, value, auto_encode):
     if schema and schema.attribute_types:
         if ';' in name:
             name = name.split(';')[0]
-
-        if schema.object_classes and name.lower() == 'objectclass':
+        if check_names and schema.object_classes and name.lower() == 'objectclass':
             if to_unicode(value).lower() not in conf_classes_excluded_from_check and to_unicode(value) not in schema.object_classes:
                 raise LDAPObjectClassError('invalid class in objectClass attribute: ' + str(value))
-
-        if name not in schema.attribute_types and name.lower() not in conf_attributes_excluded_from_check:
+        elif check_names and name not in schema.attribute_types and name.lower() not in conf_attributes_excluded_from_check:
             raise LDAPAttributeError('invalid attribute ' + name)
-
-        # encodes to utf-8 for well known Unicode LDAP syntaxes
-        if auto_encode and (schema.attribute_types[name].syntax in conf_utf8_syntaxes or name.lower() in conf_utf8_types):
+        else:  # try standard validators
+            validator = find_attribute_validator(schema, name, validator)
+            validated = validator(value)
+            if validated is False:
+                try:  # checks if the value is a byte value erroneously converted to a string (as "b'1234'"), this is a common case in Python 3 when encoding is not specified
+                    if value[0:2] == "b'" and value [-1] == "'":
+                        value = to_raw(value[2:-1])
+                        validated = validator(value)
+                except Exception:
+                    raise LDAPInvalidValueError('value \'%s\' non valid for attribute \'%s\'' % (value, name))
+            if validated is False:
+                raise LDAPInvalidValueError('value \'%s\' non valid for attribute \'%s\'' % (value, name))
+            elif validated is not True:  # a valid LDAP value equivalent to the actual value
+                value = validated
+        # converts to utf-8 for well known Unicode LDAP syntaxes
+        if auto_encode and ((name in schema.attribute_types and schema.attribute_types[name].syntax in conf_utf8_syntaxes) or name.lower() in conf_utf8_types):
             value = to_unicode(value)  # tries to convert from local encoding to Unicode
     return to_raw(value)
 
@@ -161,7 +188,7 @@ def prepare_filter_for_sending(raw_string):
     ints = []
     raw_string = to_raw(raw_string)
     while i < len(raw_string):
-        if (raw_string[i] == 92 or raw_string[i] == '\\') and i < len(raw_string) - 2:  # 92 is backslash
+        if (raw_string[i] == 92 or raw_string[i] == '\\') and i < len(raw_string) - 2:  # 92 (0x5C) is backslash
             try:
                 ints.append(int(raw_string[i + 1: i + 3], 16))
                 i += 2
